#!/usr/bin/perl

#usage: createXML.pl projectName

#create the XML file for DVDAuthor
$projectName=$ARGV[0];

open(XML,">$projectName.xml");

print XML <<EndXML;
<dvdauthor dest="$projectName">
  <vmgm />
   <titleset>
     <titles>
       <video widescreen="nopanscan" />
       <pgc>
         <vob file="$projectName.mpg" chapters="0,0:30,1:00,1:30,2:30,3:00,3:30,4:00"/>
       </pgc>
     </titles>
   </titleset>
 </dvdauthor>
EndXML

close(XML);
